@@ -2,13 +2,12 @@ from retry import retry
 from retry.api import retry_call
 from dataclasses import asdict
 import requests
-from time import sleep
-
+from packaging.version import parse as parse_version
 
 from uiautomator2.core import HTTPResponse, _http_request
 from kea2.adbUtils import ADBDevice, ADBStreamShell_V2
 from pathlib import Path
-from kea2.utils import getLogger
+from kea2.utils import getLogger, getProjectRoot
 
 
 from typing import IO, TYPE_CHECKING, Dict
@@ -28,6 +27,7 @@ class FastbotManager:
         self._device_output_dir = None
         ADBDevice.setDevice(options.serial, options.transport_id)
         self.dev = ADBDevice()
+        self.android_release = parse_version(self.dev.getprop("ro.build.version.release"))
 
     def _activateFastbot(self) -> ADBStreamShell_V2:
         """
@@ -70,14 +70,15 @@ class FastbotManager:
             "/data/local/tmp/x86_64/libfastbot_native.so",
         )
 
+        cwd = getProjectRoot()
         whitelist = self.options.act_whitelist_file
         blacklist = self.options.act_blacklist_file
         if bool(whitelist) ^ bool(blacklist):
             if whitelist:
-                file_to_push = cur_dir.parent / 'configs' / 'awl.strings'
+                file_to_push = cwd / 'configs' / 'awl.strings'
                 remote_path = whitelist
             else:
-                file_to_push = cur_dir.parent / 'configs' / 'abl.strings'
+                file_to_push = cwd / 'configs' / 'abl.strings'
                 remote_path = blacklist
 
             self.dev.sync.push(
@@ -197,6 +198,9 @@ class FastbotManager:
 
         shell_command += ["-v", "-v", "-v"]
 
+        if self.options.extra_args:
+            shell_command += self.options.extra_args
+
         full_cmd = ["adb"] + (["-s", self.options.serial] if self.options.serial else []) + ["shell"] + shell_command
 
 
@@ -219,7 +223,7 @@ class FastbotManager:
         if self.thread.is_running():
             logger.info("Waiting for Fastbot to exit.")
             return self.thread.wait()
-        return self.thread.poll()
+        return self.thread.poll() if self.android_release >= parse_version("7.0") else 0
 
     def start(self):
         # kill the fastbot process if runing.
