@@ -136,6 +136,8 @@ class Options:
     act_whitelist_file: str = None
     # Activity BlackList File
     act_blacklist_file: str = None
+    # Extra args
+    extra_args: List[str] = None
 
     def __setattr__(self, name, value):
         if value is None:
@@ -198,6 +200,9 @@ class PropStatistic:
     executed: int = 0
     fail: int = 0
     error: int = 0
+    
+
+PBTTestResult = NewType("PBTTestResult", Dict[PropName, PropStatistic])
 
 
 PropertyExecutionInfoStore = NewType("PropertyExecutionInfoStore", Deque["PropertyExecutionInfo"])
@@ -209,11 +214,6 @@ class PropertyExecutionInfo:
     tb: str
 
 
-class PBTTestResult(dict):
-    def __getitem__(self, key) -> PropStatistic:
-        return super().__getitem__(key)
-
-
 def getFullPropName(testCase: TestCase):
     return ".".join([
         testCase.__module__,
@@ -277,10 +277,15 @@ class JsonResult(TextTestResult):
             self.lastExecutedInfo.state = "pass"
 
         self.executionInfoStore.append(self.lastExecutedInfo)
-        
 
     def getExcuted(self, test: TestCase):
         return self.res[getFullPropName(test)].executed
+    
+    def logSummary(self):
+        fails = sum(_.fail for _ in self.res.values())
+        errors = sum(_.error for _ in self.res.values())
+
+        logger.info(f"[Property Exectution Summary] Errors:{errors}, Fails:{fails}")
 
 
 class KeaTestRunner(TextTestRunner):
@@ -465,6 +470,8 @@ class KeaTestRunner(TextTestRunner):
         else:
             self.stream.write("\n")
         self.stream.flush()
+        
+        result.logSummary()
         return result
 
     @property
